@@ -405,7 +405,7 @@ test_that("files can be split", { # see also the example
 
 test_that("file names can be cleaned", {
   x <- c("a b/c/x-y-z.txt", "d--z/z?-z. .csv", "/xxx/y y/?_?-abcd*+.txt", 
-    "", "sapif89asdh_&#-*_asdfhu.---", "!$%&\\()=?`")
+    "", "sapif89asdh_&#-*_asdfhu.---", "!$%&+()=?`")
   expect_that(got <- clean_filenames(x, demo = TRUE), shows_message())
   expect_equal(names(got), x[-1L])
   expect_equivalent(got, c("d--z/z-z.csv", "/xxx/y y/abcd.txt",
